## Product details

Enhance your cat's playtime with the Vibrant Life Mushroom Cat Scratching Post. This engaging scratching post entices your cat to scratch naturally while adding a cute, cottagecore accent to any room in your home. This mushroom-shaped scratching post features a battery-powered bird toy that chirps when touched to encourage your cat's natural hunting instincts. The mushroom cap is covered with fabric and the stem is wrapped with jute to give your cat a satisfying scratch sesh. This sturdy scratching post is designed for stability during your cat's playtime and keep you both entertained. Your cat will love the Vibrant Life Mushroom Cat Scratching Post.

Help your pets live the Vibrant Life! Our products are specially crafted with one goal in mind, seeing your pet at its very best. With a variety of offerings designed to keep animals healthy, happy and energized, Vibrant Life stands out as the brand that truly puts your pet first.


Vibrant Life Deluxe Jute Mushroom Cat Scratching Post with Dangling Bird Toy, Multicolor
Fabric-covered mushroom top feels good on the paws
Natural jute-wrapped post promotes healthy scratching
Interactive dangling bird built-in button-cell batter chirps at the touch, stimulating your feline friends’ natural hunting instincts
Designed with stability in mind
Assembly required
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Animal health concern
Claw Care
Fabric content
100% Polyester
Items included
Hanging Toy
Shape
Mushroom
More details
## Indications

Animal Health Concern
Claw Care
Directions

## Instructions
keep away from children
Fabric Care Instructions
Spot clean only.
